@@ -23,7 +23,7 @@ Usage:
   opereto environments list [<search_pattern>]
   opereto environment <environment-name>
   opereto globals list [<search_pattern>]
-  opereto diagnostics <from_iso_date> <to_iso_date>
+  opereto diagnostics <from_iso_date> <to_iso_date> [--file=OUTPUT_FILE]
   opereto token
   opereto (-h | --help)
   opereto --version
@@ -66,6 +66,8 @@ Options:
     --all                : Print all process data entities
 
     token                : Show the current token details
+    diagnostics          : Generates a diagnostics file. Requires a few additional python packages
+
     -h,--help            : Show this help message
     --version            : Show this tool version
 
@@ -90,6 +92,9 @@ from distutils.version import LooseVersion
 from pyopereto.client import OperetoClient, OperetoClientError, process_running_statuses
 from pyopereto.diagnostics import run_diagnostics
 
+logging.getLogger("matplotlib").propagate = False
+logging.getLogger('matplotlib').setLevel(logging.ERROR)
+
 
 try:
     VERSION = pkg_resources.get_distribution("pyopereto").version
@@ -695,7 +700,8 @@ def diagnostics(arguments):
 
     startdate = arguments['<from_iso_date>']
     enddate = arguments['<to_iso_date>']
-    run_diagnostics(startdate, enddate)
+    file = arguments['--file'] or None
+    run_diagnostics(startdate, enddate, file)
 
 
 def main():
